/* Atom: timecode — clickable and plain timecode links */

a.timecode,
a.timecode:visited {
    color: var(--bn-colour-accent);
    font-family: var(--bn-font-mono);
    font-size: 0.8rem;
    text-decoration: none;
    cursor: pointer;
}

span.timecode {
    color: var(--bn-colour-accent);
    font-family: var(--bn-font-mono);
    font-size: 0.8rem;
}

a.timecode:hover {
    text-decoration: underline;
}

.timecode-bracket {
    color: var(--bn-colour-muted);
}
