"""Bristlenose: User-research transcription and quote extraction engine.

Copyright (C) 2025-2026 Martin Storey <martin@cassiocassio.co.uk>
SPDX-License-Identifier: AGPL-3.0-only
"""

__version__ = "0.6.5"
